@@ -1,3 +1,4 @@
+C Output from Public domain Ratfor, version 1.0
       subroutine delseg(delsgs,ndel,nadj,madj,x,y,ntot,ind,nerror)
       implicit double precision(a-h,o-z)
       dimension nadj(-3:ntot,0:madj), x(-3:ntot), y(-3:ntot)
@@ -5,29 +6,31 @@
       logical value
       npd = ntot-4
       kseg = 0
-      do 23000 i1 = 2,npd 
+      do23000 i1 = 2,npd 
       i = ind(i1)
-      do 23002 j1 = 1,i1-1 
+      do23002 j1 = 1,i1-1 
       j = ind(j1)
       call adjchk(i,j,value,nadj,madj,ntot,nerror)
-      if(.not.(nerror.gt.0))goto 23004
+      if(nerror.gt.0)then
       return
-23004 continue
-      if(.not.(value))goto 23006
+      endif
+      if(value)then
       kseg = kseg+1
-      if(.not.(kseg .gt. ndel))goto 23008
+      if(kseg .gt. ndel)then
       nerror = 14
       return
-23008 continue
+      endif
       delsgs(1,kseg) = x(i)
       delsgs(2,kseg) = y(i)
       delsgs(3,kseg) = x(j)
       delsgs(4,kseg) = y(j)
       delsgs(5,kseg) = i1
       delsgs(6,kseg) = j1
-23006 continue
+      endif
 23002 continue
+23003 continue
 23000 continue
+23001 continue
       ndel = kseg
       return
       end
